



clingo --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
clasp --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
reify --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
lpconvert --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
gringo --version
IF %ERRORLEVEL% NEQ 0 exit /B 1
exit /B 0
